@@ -1,6 +1,6 @@
 #!/home/chrisarg/perl5/perlbrew/perls/current/bin/perl
 package Bit::Set::DB::OO;
-$Bit::Set::DB::OO::VERSION = '0.09';
+$Bit::Set::DB::OO::VERSION = '0.10';
 use strict;
 use warnings;
 
@@ -17,7 +17,7 @@ use FFI::Platypus;
 # Creation and Destruction
 
 package Bit::Set::DB {
-$Bit::Set::DB::VERSION = '0.09';
+$Bit::Set::DB::VERSION = '0.10';
 sub new {
         my ( $class, $length, $num_of_bitsets ) = @_;
         my $self = BitDB_new( $length, $num_of_bitsets );
@@ -190,7 +190,7 @@ from the C<Bit> C library
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -494,6 +494,10 @@ This distribution provides the library Bit so that it can be used by other Perl
 distributions that are on CPAN. It will download Bit from Github and will build 
 the (static and dynamic) versions of the library for use by other Perl modules.
 
+=item L<benchmarking-bits|https://github.com/chrisarg/benchmarking-bits>
+
+A collection of benchmarking scripts for various bitset libraries in C and Perl.
+
 =item L<Bit|https://github.com/chrisarg/Bit>
 
 Bit is a high-performance, uncompressed bitset implementation in C, optimized 
@@ -520,6 +524,13 @@ Object Oriented interface to the Bit::Set module.
 
 Procedural interface to the containerized operations of the Bit library.
 
+=item L<Bit::Vector|https://metacpan.org/pod/Bit::Vector>
+
+Efficient bit vector, set of integers and "big int" math library
+
+=item L<Lucy::Object::BitVector|https://metacpan.org/dist/Lucy/view/lib/Lucy/Object/BitVector.pod>
+
+Bit vector implementation used in the L<Lucy|https://metacpan.org/pod/Lucy> search engine library.
 
 =back
 
